
--[[

name:   Prefs Manager
vers:   1.0.0
desc:   A simple prefs manager. loads and saves pref files
auth:   by Cliff Earl, Antix Software
date:   June 2016
legal:  Distribute freely but please leave my credits intact.

--]]

Prefs = Core.class()

require("json")

function Prefs:init() -- Startup
  
  self.crypt = SimpleCrypt.new()

  self.soundEnabled           = true -- Default prefs
  self.soundVolume            = .50
  self.musicEnabled           = true
  self.musicVolume            = .25
end

function Prefs:empty(table) -- Clear table
  for k in next,table do
    local t = type(k)
    if k == "table" then
      self:empty(k)
    end
    table[k] = nil
  end
end

function Prefs:exists(name) -- Return true if file exists
  local file = io.open(name, "rb")
  if file == nil then
    return false
  end
  file:close()
  return true
end

function Prefs:loadPrefs() --Load prefs and create defaults if the file is not found
  local filename = "|D|prefs.json"
  if self:exists(filename) then
    local file = io.open(filename, "r") -- Load and set prefs
    local data = file:read( "*a" )
    file:close()
    local p = json.decode( self.crypt:decrypt(data) )
    data = nil
    
		for key, value in pairs(p) do
			self[key]= value
		end
    
    self:empty(p) -- Expunge
    p = nil
  else
    
    self:savePrefs()
  end
end

function Prefs:savePrefs() -- Save prefs file
  local t1 = os.timer()
  
  local file = io.open("|D|prefs.json", "w+")
  local p = {
    soundEnabled            = self.soundEnabled,
    soundVolume             = self.soundVolume,
    musicEnabled            = self.musicEnabled,
    musicVolume             = self.musicVolume,
  }
  
  local data = self.crypt:encrypt( json.encode(p) )
  file:write(data)
  file:close()
  self:empty(p)
  p = nil
  data = nil
  file = nil
end
